summaryrefslogtreecommitdiffstats
path: root/lib/koproperty/editoritem.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:02:43 -0600
commitaea627236e4de24599c3e30617cf264c3c1b7d40 (patch)
tree467e13ca5a7eb0ab292259289ecc3572f53c5eae /lib/koproperty/editoritem.h
parent786304c6211f35ddc4cdd54b7aa7985fef4a2e70 (diff)
downloadkoffice-aea627236e4de24599c3e30617cf264c3c1b7d40.tar.gz
koffice-aea627236e4de24599c3e30617cf264c3c1b7d40.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'lib/koproperty/editoritem.h')
-rw-r--r--lib/koproperty/editoritem.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/lib/koproperty/editoritem.h b/lib/koproperty/editoritem.h
index fc703239..a1300e5a 100644
--- a/lib/koproperty/editoritem.h
+++ b/lib/koproperty/editoritem.h
@@ -44,7 +44,7 @@ class GroupWidget;
\author Jaroslaw Staniek <js@iidea.pl>
@internal
*/
-class EditorItem : public KListViewItem
+class EditorItem : public TDEListViewItem
{
public:
typedef TQAsciiDict<EditorItem> Dict;
@@ -56,7 +56,7 @@ class EditorItem : public KListViewItem
TQListViewItem *after=0);
//! Two helper contructors for subclass
- EditorItem(KListView *parent);
+ EditorItem(TDEListView *parent);
EditorItem(EditorItem *parent, const TQString &text);
EditorItem(EditorItem *parent, EditorItem *after, const TQString &text);
@@ -66,12 +66,12 @@ class EditorItem : public KListViewItem
Property* property();
protected:
/*! Reimplemented from KListViewItem to draw custom contents. Properties names are wriiten in bold if
modified. Also takes care of drawing borders around the cells as well as pixmaps or colors if necessary.
*/
virtual void paintCell(TQPainter *p, const TQColorGroup & cg, int column, int width, int align);
/*! Reimplemented from KListViewItem to draw custom contents. It takes care of drawing the [+] and [-]
signs only if the item has children.
*/
virtual void paintBranches(TQPainter *p, const TQColorGroup &cg, int w, int y, int h);
@@ -102,7 +102,7 @@ class EditorGroupItem : public EditorItem
protected:
virtual void init(const TQString &icon);
/*! Reimplemented from KListViewItem to draw custom contents. */
virtual void paintCell(TQPainter *p, const TQColorGroup & cg, int column, int width, int align);
virtual void setup();
virtual int compare( TQListViewItem *i, int col, bool ascending ) const;
@@ -115,7 +115,7 @@ class EditorGroupItem : public EditorItem
class EditorDummyItem : public EditorItem
{
public:
- EditorDummyItem(KListView *parent);
+ EditorDummyItem(TDEListView *parent);
virtual ~EditorDummyItem();
protected:
@@ -66,12 +66,12 @@ class EditorItem : public KListViewItem
Property* property();
protected:
- /*! Reimplemented from KListViewItem to draw custom contents. Properties names are wriiten in bold if
+ /*! Reimplemented from TDEListViewItem to draw custom contents. Properties names are wriiten in bold if
modified. Also takes care of drawing borders around the cells as well as pixmaps or colors if necessary.
*/
@@ -66,12 +66,12 @@ class EditorItem : public KListViewItem
*/
virtual void paintCell(TQPainter *p, const TQColorGroup & cg, int column, int width, int align);
- /*! Reimplemented from KListViewItem to draw custom contents. It takes care of drawing the [+] and [-]
+ /*! Reimplemented from TDEListViewItem to draw custom contents. It takes care of drawing the [+] and [-]
signs only if the item has children.
*/
@@ -102,7 +102,7 @@ class EditorGroupItem : public EditorItem
protected:
virtual void init(const TQString &icon);
- /*! Reimplemented from KListViewItem to draw custom contents. */
+ /*! Reimplemented from TDEListViewItem to draw custom contents. */
virtual void paintCell(TQPainter *p, const TQColorGroup & cg, int column, int width, int align);
virtual void setup();